@@ -1,47 +1,57 @@
 """Decorator that prevents infinite recursion for `__repr__` methods."""
 
-import functools
-import contextvars
+from __future__ import absolute_import, division, print_function
 
-from tippo import Counter, Callable, Optional, TypeVar, Literal, overload
+import functools
+
+import six
+from tippo import TYPE_CHECKING, Counter, TypeVar, overload
+
+from .context_vars import ContextVar
+
+if TYPE_CHECKING:
+    from tippo import Callable, Literal
 
 __all__ = ["recursive_repr"]
 
 
 _T = TypeVar("_T")
 
-_reprs: contextvars.ContextVar[Counter[int]] = contextvars.ContextVar("_reprs")
+_reprs = ContextVar("_reprs")  # type: ContextVar[Counter[int]]
 
 
 @overload
 def recursive_repr(
-    maybe_func: Callable[..., _T],
-    max_depth: Optional[int] = 1,
-    max_repr: str = "...",
-) -> Callable[..., _T]:
+    maybe_func,  # type: Callable[..., _T]
+    max_depth=1,  # type: int | None
+    max_repr="...",  # type: str
+):
+    # type: (...) -> Callable[..., _T]
     pass
 
 
 @overload
 def recursive_repr(
-    maybe_func: Literal[None],
-    max_depth: Optional[int] = 1,
-    max_repr: str = "...",
-) -> Callable[[Callable[..., _T]], Callable[..., _T]]:
+    maybe_func,  # type: Literal[None]
+    max_depth=1,  # type: int | None
+    max_repr="...",  # type: str
+):
+    # type: (...) -> Callable[[Callable[..., _T]], Callable[..., _T]]
     pass
 
 
 def recursive_repr(maybe_func=None, max_depth=1, max_repr="..."):
     """
     Decorate a representation method/function to prevent infinite recursion.
-
     :param maybe_func: The '__repr__' and/or '__str__' method/function or None.
     :param max_depth: Maximum depth.
     :param max_repr: Repr text to return after max depth has been reached.
     :return: Decorated method function or decorator.
     """
 
-    def decorator(func: Callable[..., _T]) -> Callable[..., _T]:
+    def decorator(func):
+        # type: (Callable[..., _T]) -> Callable[..., _T]
+
         @functools.wraps(func)
         def decorated(*args, **kwargs):
 
@@ -49,7 +59,10 @@ def recursive_repr(maybe_func=None, max_depth=1, max_repr="..."):
             try:
                 self = args[0]
             except IndexError:
-                raise RuntimeError("'recursive_repr' needs to decorate a class/instance method") from None
+                error = "'recursive_repr' needs to decorate a class/instance method"
+                exc = RuntimeError(error)
+                six.raise_from(exc, None)
+                raise exc
             self_id = id(self)
 
             # Get reprs counter for current context and increment it for self.
